.. _index-main:

=================================
DynTS
=================================

.. rubric:: Timeseries analysis and manipulation including a domain specific language
			for building and evaluating timeseries expressions. It includes abstract
			classes for loading data when evaluating expressions.

**Getting Started**
:ref:`Overview, Installation and Development <intro-overview>`
	
**Where does it get the data?**
Pluggable :class:`dynts.data.DataProvider`.

**How econometric calculations are performed?**
Extendible :class:`dynts.TimeSeries` backend classes.

**Dynts is in constant development, with new functionalities added on a daily basis.**

Contents						
==================

.. toctree::
   :maxdepth: 1
   
   interface/index
   dsl/index
   backends/index
   provider/index
   functions
   formatters
   internals/index
   maths/index
   web/index
   changelog

	
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _Timeseries: http://en.wikipedia.org/wiki/Time_series
